@@ -2,7 +2,7 @@ package Smart::Options;
 use strict;
 use warnings;
 use 5.010001;
-our $VERSION = '0.056';
+our $VERSION = '0.06';
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -26,6 +26,8 @@ sub new {
         type     => {},
         subcmd   => {},
         coerce   => {},
+        env      => {},
+        env_prefix => '',
     }, $pkg;
 
     if ($opt{add_help} // 1) {
@@ -74,6 +76,7 @@ sub _set_flag {
 
 sub boolean { shift->_set_flag('boolean', @_) }
 sub demand { shift->_set_flag('demand', @_) }
+sub env { shift->_set_flag('env', @_) }
 
 sub options {
     my $self = shift;
@@ -98,6 +101,7 @@ sub coerce {
 }
 
 sub usage { $_[0]->{usage} = $_[1]; $_[0] }
+sub env_prefix { $_[0]->{env_prefix} = $_[1]; $_[0] }
 
 sub _get_opt_desc {
     my ($self, $option) = @_;
@@ -245,11 +249,16 @@ sub parse {
                 _set_v2a($argv, $option, $2);
             }
         }
-        elsif ($arg =~ /^(-(\w(?:\w|-|\.)*)|--((?:\w|-|\.)+))$/) {
+        elsif ($arg =~ /^(-(\w)|--((?:\w|-|\.)+))$/) {
             if ($key) {
                 $argv->{$key} = 1;
             }
             my $opt = $2 // $3;
+            if ($opt =~ /^no\-(.+)$/) {
+                my $option = $self->_get_real_name($1);
+                $argv->{$option} = 0;
+                next;
+            }
             ($opt, my $k) = split(/\./, $opt);
             my $option = $self->_get_real_name($opt);
             if ($boolean->{$option}) {
@@ -265,6 +274,21 @@ sub parse {
                 $nest_key = $k;
             }
         }
+        elsif ($arg =~ /^-(\w(?:\w|-|\.)+)$/) {
+            if ($key) {
+                $argv->{$key} = 1;
+            }
+            my $opt_str = $1;
+            if ($opt_str =~ /^(.)([0-9])+$/) {
+                my $option = $self->_get_real_name($1);
+                $argv->{$option} = $2;
+            } else {
+                for (split //, $opt_str) {
+                    my $option = $self->_get_real_name($_);
+                    $argv->{$option} = 1;
+                }
+            }
+        }
         elsif ($arg =~ /^--$/) {
             # stop parsing
             $stop = 1;
@@ -311,6 +335,13 @@ sub parse {
         $argv->{_} = \@args;
     }
 
+    for my $env (keys %{$self->{env}}) {
+        if (defined($ENV{uc($self->{env_prefix}."_$env")})) {
+            my $option = $self->_get_real_name($env);
+            $argv->{$option} //= $ENV{uc($self->{env_prefix}."_$env")};
+        }
+    }
+
     while (my ($key, $val) = each %{$self->{default}}) {
         my $opt = $self->_get_real_name($key);
         if (ref($val) && ref($val) eq 'CODE') {
@@ -647,7 +678,7 @@ Kan Fushihara E<lt>kan.fushihara@gmail.comE<gt>
 
 =head1 SEE ALSO
 
-https://github.com/substack/node-optimist
+https://www.npmjs.com/package/minimist
 
 L<GetOpt::Casual>, L<opts>, L<GetOpt::Compat::WithCmd>
 
